@@ -3,12 +3,13 @@ import click
 from sendbee_api.auth import SendbeeAuth
 from sendbee_api.teams.client import Teams
 from sendbee_api.contacts.client import Contacts
+from sendbee_api.rate_limit.client import RateLimit
 from sendbee_api.automation.client import Automation
 from sendbee_api.conversations.client import Messages
 from sendbee_api.exceptions import SendbeeRequestApiException
 
 
-class Client(Contacts, Messages, Automation, Teams):
+class Client(Contacts, Messages, Automation, Teams, RateLimit):
     """Main API class. Sets all API calls."""
 
     base_url = 'api-v2.sendbee.io'
